<?php
/**
 * CT Settings Theme Settings
 *
 * @package      CT Settings
 * @author       Thomas Griffin <http://thomasgriffinmedia.com/>
 * @copyright    Copyright (c) 2011, Thomas Griffin
 * @license      http://opensource.org/licenses/gpl-2.0.php GNU Public License
 *
 */


/* Define our constants
------------------------------------------------------------ */

define( 'CTSETTINGS_SETTINGS_FIELD', 'ct-settings' );


/* Setup default options
------------------------------------------------------------ */

/**
 * ctsettings_default_theme_options function.
 *
 * This function stores the default CT Settings theme options. It can be filtered using ctsettings_default_theme_options.
 *
 * @return $options, filtered by ctsettings_default_theme_options
 *
 * @since 1.0.0
 *
 */
function ctsettings_default_theme_options() {
	$options = array(
		'ctsettings_facebook_link' 	=> 0,
		'ctsettings_twitter_link' 	=> 0,
		'ctsettings_google_link' 	=> 0
	);
	return apply_filters( 'ctsettings_default_theme_options', $options );
}


/* Sanitize any inputs
------------------------------------------------------------ */

add_action( 'genesis_settings_sanitizer_init', 'ctsettings_sanitize_inputs' );
/**
 * ctsettings_sanitize_inputs function.
 *
 * This function accesses Genesis' sanitization class to sanitize all users inputs and options in the CT Settings settings area.
 *
 * @since 1.0.0
 *
 */ 
function ctsettings_sanitize_inputs() {
    genesis_add_option_filter( 'one_zero', CTSETTINGS_SETTINGS_FIELD, array( 'ctsettings_facebook_link', 'ctsettings_twitter_link', 'ctsettings_google_link' ) );
}


/* Register our settings and add the options to the database
------------------------------------------------------------ */

add_action( 'admin_init', 'ctsettings_register_settings' );
/**
 * ctsettings_register_settings function.
 *
 * This function registers the settings for use in the CT Settings theme settings area. It also restores default options when
 * the Reset button is selected.
 *
 * @since 1.0.0
 *
 */
function ctsettings_register_settings() {
	register_setting( CTSETTINGS_SETTINGS_FIELD, CTSETTINGS_SETTINGS_FIELD );
	add_option( CTSETTINGS_SETTINGS_FIELD, ctsettings_default_theme_options() );
	
	if ( genesis_get_option( 'reset', CTSETTINGS_SETTINGS_FIELD ) ) {
		update_option( CTSETTINGS_SETTINGS_FIELD, ctsettings_default_theme_options() );
		genesis_admin_redirect( CTSETTINGS_SETTINGS_FIELD, array( 'reset' => 'true' ) );
		exit;
	}
}


/* Admin notices for when options are saved/reset
------------------------------------------------------------ */

add_action( 'admin_notices', 'ctsettings_theme_settings_notice' );
/**
 * ctsettings_theme_settings_notice function.
 *
 * This function displays admin notices when the user updates CT Settings' theme settings area.
 *
 * @since 1.0.0
 *
 */
function ctsettings_theme_settings_notice() {
	if ( ! isset( $_REQUEST['page'] ) || $_REQUEST['page'] != CTSETTINGS_SETTINGS_FIELD )
		return;

	if ( isset( $_REQUEST['reset'] ) && 'true' == $_REQUEST['reset'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings reset.', 'genesis' ) . '</strong></p></div>';
	elseif ( isset( $_REQUEST['settings-updated'] ) && 'true' == $_REQUEST['settings-updated'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings saved.', 'genesis' ) . '</strong></p></div>';
}


/* Register our theme options page
------------------------------------------------------------ */

add_action( 'admin_menu', 'ctsettings_theme_options' );
/**
 * ctsettings_theme_options function.
 *
 * This function registers the CT Settings settings page and prepares the styles, scripts and metaboxes to be loaded.
 *
 * @global $_ctsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function ctsettings_theme_options() {
	global $_ctsettings_settings_pagehook;
	$_ctsettings_settings_pagehook = add_submenu_page( 'genesis', 'CT Settings', 'CT Settings', 'edit_theme_options', CTSETTINGS_SETTINGS_FIELD, 'ctsettings_theme_options_page' );

	//add_action( 'load-'.$_ctsettings_settings_pagehook, 'ctsettings_settings_styles' );
	add_action( 'load-'.$_ctsettings_settings_pagehook, 'ctsettings_settings_scripts' );
	add_action( 'load-'.$_ctsettings_settings_pagehook, 'ctsettings_settings_boxes' );
}


/* Setup our scripts
------------------------------------------------------------ */

/**
 * ctsettings_settings_scripts function.
 *
 * This function enqueues the scripts needed for the CT Settings settings page.
 *
 * @global $_ctsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function ctsettings_settings_scripts() {	
	global $_ctsettings_settings_pagehook;
	wp_enqueue_script( 'common' );
	wp_enqueue_script( 'wp-lists' );
	wp_enqueue_script( 'postbox' );
}


/* Setup our metaboxes
------------------------------------------------------------ */

/**
 * ctsettings_settings_boxes function.
 *
 * This function sets up the metaboxes to be populated by their respective callback functions.
 *
 * @global $_ctsettings_settings_pagehook
 *
 * @since 1.0.0
 *
 */
function ctsettings_settings_boxes() {
	global $_ctsettings_settings_pagehook;
	add_meta_box( 'ctsettings-social-box', __( 'CT Settings Social Sharing', 'genesis' ), 'ctsettings_social_metabox', $_ctsettings_settings_pagehook, 'main' );
}


/* Add our custom post metabox for social sharing
------------------------------------------------------------ */

/**
 * ctsettings_social_metabox function.
 *
 * Callback function for the CT Settings Social Sharing metabox.
 *
 * @since 1.0.0
 *
 */
function ctsettings_social_metabox() { ?>

	<p><?php _e( 'Check any of the following if you want Facebook, Twitter or Google+ buttons for your posts.', 'genesis' ); ?></p>
	<table class="form-table ctsettings-social">
		<tbody>
			<tr valign="top">
				<th scope="row">
					<input type="checkbox" name="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_facebook_link]" id="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_facebook_link]" value="1" <?php checked( 1, genesis_get_option( 'ctsettings_facebook_link', CTSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_facebook_link]"><?php _e( 'Include a Facebook Like button on your posts?', 'genesis' ); ?></label>
				</th>
			</tr>
			<tr valign="top">
				<th scope="row">
					<input type="checkbox" name="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_twitter_link]" id="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_twitter_link]" value="1" <?php checked( 1, genesis_get_option( 'ctsettings_twitter_link', CTSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_twitter_link]"><?php _e( 'Include a Twitter Tweet button on your posts?', 'genesis' ); ?></label>
				</th>
			</tr>
			<tr valign="top">
				<th scope="row">
					<input type="checkbox" name="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_google_link]" id="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_google_link]" value="1" <?php checked( 1, genesis_get_option( 'ctsettings_google_link', CTSETTINGS_SETTINGS_FIELD ) ); ?> /> <label for="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[ctsettings_google_link]"><?php _e( 'Include a Google Plus button on your posts?', 'genesis' ); ?></label>
				</th>
			</tr>
		</tbody>
	</table>
	
<?php }


/* Set the screen layout to one column
------------------------------------------------------------ */

add_filter( 'screen_layout_columns', 'ctsettings_settings_layout_columns', 10, 2 );
/**
 * ctsettings_settings_layout_columns function.
 *
 * This function sets the column layout to one for the CT Settings settings page.
 *
 * @param mixed $columns
 * @param mixed $screen
 * @return $columns
 *
 * @since 1.0.0
 *
 */
function ctsettings_settings_layout_columns( $columns, $screen ) {
	global $_ctsettings_settings_pagehook;
	if ( $screen == $_ctsettings_settings_pagehook ) {
		$columns[$_ctsettings_settings_pagehook] = 1;
	}
	return $columns;
}


/* Build our theme options page
------------------------------------------------------------ */

/**
 * ctsettings_theme_options_page function.
 *
 * This function displays the content for the CT Settings settings page, builds the forms and outputs the metaboxes.
 *
 * @global $_ctsettings_settings_pagehook
 * @global $screen_layout_columns
 *
 * @since 1.0.0
 *
 */
function ctsettings_theme_options_page() { 

	global $_ctsettings_settings_pagehook, $screen_layout_columns;
	$width = "width: 99%;";
	$hide2 = $hide3 = " display: none;";
	?>	
	
	<div id="ctsettings" class="wrap genesis-metaboxes">
		<form method="post" action="options.php">
		
			<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
			<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>
			<?php settings_fields( CTSETTINGS_SETTINGS_FIELD ); ?>
			
			<?php screen_icon( 'options-general' ); ?>
			
			<h2>
				<?php _e( 'CT Settings - Theme Settings', 'genesis' ); ?>
				<input type="submit" class="button-primary genesis-h2-button" value="<?php _e( 'Save Settings', 'genesis' ) ?>" />
				<input type="submit" class="button-highlighted genesis-h2-button" name="<?php echo CTSETTINGS_SETTINGS_FIELD; ?>[reset]" value="<?php _e( 'Reset Settings', 'genesis' ); ?>" onclick="return genesis_confirm('<?php echo esc_js( __( 'Are you sure you want to reset?', 'genesis' ) ); ?>');" />
			</h2>
		
			<div class="metabox-holder">
				<div class="postbox-container" style="<?php echo $width; ?>">
					<?php do_meta_boxes( $_ctsettings_settings_pagehook, 'main', null ); ?>
				</div>
			</div>
		
		</form>
	</div>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			// close postboxes that should be closed
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			// postboxes setup
			postboxes.add_postbox_toggles('<?php echo $_ctsettings_settings_pagehook; ?>');
		});
		//]]>
	</script>

<?php }